#ifndef DISPLAY_AUTO_CHECK
#define DISPLAY_AUTO_CHECK
#include "TYW_stdint.h"
enum DisplayFont
{
    em_0,
    em_1,
    em_2,
    em_3,
    em_4,
    em_5,
    em_6,
    em_7,
    em_8,
    em_9,
    em_HENG,
    em_A,
    em_B,
    em_C,
    em_D,
    em_E,
    em_F,
    em_G,
    em_H,
    em_I,
    em_J,
    em_K,
    em_L,
    em_M,
    em_N,
    em_O,
    em_P,
    em_Q,
    em_R,
    em_S,
    em_T,
    em_U,
    em_V,
    em_W,
    em_X,
    em_Y,
    em_Z,
    em_DIAN,
    em_cuo,
    em_dui,
};


extern unsigned int Display_Menu_Type;
extern uint32_t odo_val_Back ;
void GeneralInfoDisp(unsigned char  *p, unsigned short x, unsigned short y);
void Display_Title_Info(void);
void Display_Version_Info(uint32_t ON_OFF);

extern void HW_Static_Current_Check(uint32_t cmd);
void HW_Voltage_Check(uint32_t cmd);
void Display_TFT_Clear(void);
void Display_Add(void);
unsigned int Get_Display_Type(void);
void General_Number_Disp(unsigned char *p, unsigned short x, unsigned short y);
void General_Number_Disp___No_Wrap(unsigned char *p, unsigned short x, unsigned short y);
void Display_Sub(void);
void Display_PageNum(void);
extern void Voltage_UDS__Display(void);
extern void FUEL_UDS__Display(uint8_t option);
void Display_Init(void);

extern void Send_ODO_Init(void);
void Display_Send_ODO(uint8_t fuel);

void Display_Set_Buff(void);
extern void Send_Init(void);

void Buzzer_Start(void);
void Buzzer_Stop(void);
extern void Buzzer_Init(void);
extern void Buzzer_Warning(void);
void Display_Send_Vspead(uint8_t menu);
extern void Get_static_Current(void);

void GUI_General_Digit_Display(uint32_t Digit, const uint8_t *Font[], uint8_t Len, uint8_t Blank, const uint16_t *px, uint16_t y);
void GUI_Display_Version_Code_Service(uint8_t StarX, uint16_t PosY, uint8_t * Str, const uint8_t * Version[] , uint8_t SpaceKeySize);

extern uint8_t UDS_Warning_Voltage;

extern const uint16_t BackLightDigitNum09PosX[];
extern const uint8_t *Num_09[];
extern const uint8_t *Num_10_03[];
extern const uint8_t *Num_13[];
extern const uint8_t *Num_30[];

extern const uint8_t * Letter_Num_11[];
extern uint8_t writeflag;
extern uint8_t UUIDX;
extern uint8_t UIDNumber2[10];
void Display_TFT_Clear_UID(void);
extern void Display_TFT_Clear_UID2(void);
extern const unsigned char gImage_dui11[];
#define PCodeText_Space_size 2//故障文字 英文空格的像素数
#endif
